@@ -1,6 +1,6 @@
 import argparse
 
-from ._nbproject_cli import init, reqs, sync
+from ._nbproject_cli import init, publish, reqs, sync
 
 
 def main():
@@ -19,13 +19,16 @@ def main():
         "--deps",
         "-d",
         action="store_true",
-        help="parse dependencies from the notebooks",
+        help=(
+            "parse dependencies from the notebooks and pin versions from the current"
+            " environment"
+        ),
     )
     parser_sync.add_argument(
-        "--versions",
-        "-v",
+        "--no-versions",
+        "-nv",
         action="store_true",
-        help="also pin the versions from the current environment",
+        help="do not pin the versions from the current environment",
     )
 
     parser_reqs = subparsers.add_parser("reqs", help="create requirments.txt")
@@ -33,14 +36,19 @@ def main():
         "files_dirs", nargs="+", help="create requirments.txt for these files"
     )
 
+    parser_publish = subparsers.add_parser("publish", help="pubish the notebooks")
+    parser_publish.add_argument("files_dirs", nargs="+", help="publish these notebooks")
+
     args = parser.parse_args()
 
     if args.cmd == "init":
         init()
     elif args.cmd == "sync":
-        sync(args.files_dirs, args.deps, args.versions)
+        sync(args.files_dirs, args.deps, not args.no_versions)
     elif args.cmd == "reqs":
         reqs(args.files_dirs)
+    elif args.cmd == "publish":
+        publish(args.files_dirs)
 
 
 if __name__ == "__main__":
