@@ -8,13 +8,12 @@ from ._logger import logger
 from .dev._dependency import infer_dependencies_from_nb
 from .dev._initialize import initialize_metadata
 from .dev._jupyter_communicate import notebook_path
-from .dev._jupyter_lab_commands import _restart_notebook, _save_notebook
+from .dev._jupyter_lab_commands import _reload_and_restart_notebook, _save_notebook
 from .dev._notebook import read_notebook, write_notebook
 
 _filepath = None
 _env = None
 _time_run = None
-_time_header_executed = None
 
 
 def table_html(rows: list):
@@ -107,23 +106,16 @@ def header(filepath=None, env=None):
     - If the notebook has no nbproject metadata, initializes & writes metadata to disk.
     - Starts tracking dependencies.
     """
-    # We'll never want to immediately run this again as it's run on import
-    if (
-        _time_header_executed is not None  # noqa
-        and (datetime.now() - _time_header_executed).total_seconds() < 0.1  # noqa
-    ):
-        return None
     filepath_env = filepath, env
 
     if filepath is None:
         filepath_env = notebook_path(return_env=True)
         if filepath_env is None:
-            if _time_header_executed is not None:
-                logger.info(
-                    "Can't infer the name of the current notebook, "
-                    "you are probably not inside a Jupyter notebook. "
-                    "Please call `header(filepath='your-file.ipynb')`."
-                )
+            logger.info(
+                "Can't infer the name of the current notebook, "
+                "you are probably not inside a Jupyter notebook. "
+                "Please call `header(filepath='your-file.ipynb')`."
+            )
             return None
         filepath = filepath_env[0]
 
@@ -141,11 +133,17 @@ def header(filepath=None, env=None):
         raise RuntimeError("Try passing the filepath manually to nbproject.Header().")
     # initialize
     if "nbproject" not in nb.metadata:
-        logger.info(
-            "To initialize nbproject for this notebook:\n"  # noqa
-            "- In Jupyter Lab: confirm restart when asked.\n"
-            "- In Jupyter Notebook & VS Code: reload the notebook from disk."
-        )
+        if env == "lab":
+            msg = "Hit the restart button when asked."
+        else:
+            msg = (
+                "Hit save & reload from disk, i.e, *discard* editor content. If you do"
+                " not want to lose editor changes, hit save *before* running"
+                " `header()`. Consider using Jupyter Lab for a seamless interactive"
+                " experience."
+            )
+        logging_message = f"To initialize nbproject: {msg}"
+        logger.info(logging_message)
 
         if env == "lab":
             _save_notebook()
@@ -161,7 +159,9 @@ def header(filepath=None, env=None):
             # reload the notebook with metadata by the frontend
             # otherwise Jupyter lab notices the mismatch
             # and shows a confusing dialogue
-            _restart_notebook()
+            _reload_and_restart_notebook()
+        else:
+            raise SystemExit(f"Init complete. {msg}")
 
     # read from ipynb metadata and add on-the-fly computed metadata
     else:
@@ -201,13 +201,9 @@ def header(filepath=None, env=None):
 
         display_html(table_html(table))
 
-    # make filepath available through API
-    global _filepath
-    global _env
+        # make filepath available through API
+        global _filepath
+        global _env
 
-    _filepath = filepath
-    _env = env
-
-
-header()
-_time_header_executed = datetime.now()
+        _filepath = filepath
+        _env = env
