@@ -16,10 +16,12 @@ def pytest_collection_modifyitems(session, config, items):
 def pytest_sessionfinish(session, exitstatus):
     test_cli_folder = Path(__file__).parents[1] / "docs/guides/"
 
-    nbproj_file = test_cli_folder / "nbproject_metadata.yml"
+    nbproj_file = (
+        test_cli_folder / "example-project-uninitialized/nbproject_metadata.yml"
+    )
     nbproj_file.unlink(missing_ok=True)
 
-    reqs_subfolders = ["", "example-project/"]
+    reqs_subfolders = ["example-project-uninitialized/", "example-project/"]
     for reqs_subfolder in reqs_subfolders:
         reqs_file = test_cli_folder / (reqs_subfolder + "requirments.txt")
         reqs_file.unlink(missing_ok=True)
