@@ -7,8 +7,8 @@ from nbproject.dev._jupyter_communicate import (
     running_servers,
 )
 from nbproject.dev._jupyter_lab_commands import (
+    _reload_and_restart_notebook,
     _reload_shutdown,
-    _restart_notebook,
     _save_notebook,
 )
 
@@ -41,4 +41,4 @@ def test_jupyter_not_running():
 def test_juplab_nothing_happens():
     _save_notebook()
     _reload_shutdown()
-    _restart_notebook()
+    _reload_and_restart_notebook()
